@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2018-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2018-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -49,6 +49,7 @@ struct _AsRelationClass
  * @AS_RELATION_KIND_UNKNOWN:		Unknown kind
  * @AS_RELATION_KIND_REQUIRES:		The referenced item is required by the component
  * @AS_RELATION_KIND_RECOMMENDS:	The referenced item is recommended
+ * @AS_RELATION_KIND_SUPPORTS:		The referenced item is supported
  *
  * Type of a component's relation to other items.
  **/
@@ -56,6 +57,7 @@ typedef enum  {
 	AS_RELATION_KIND_UNKNOWN,
 	AS_RELATION_KIND_REQUIRES,
 	AS_RELATION_KIND_RECOMMENDS,
+	AS_RELATION_KIND_SUPPORTS,
 	/*< private >*/
 	AS_RELATION_KIND_LAST
 } AsRelationKind;
@@ -70,6 +72,8 @@ typedef enum  {
  * @AS_RELATION_ITEM_KIND_FIRMWARE:		A device firmware requirement (used by fwupd)
  * @AS_RELATION_ITEM_KIND_CONTROL:		An input method for users to control software
  * @AS_RELATION_ITEM_KIND_DISPLAY_LENGTH:	Display edge length
+ * @AS_RELATION_ITEM_KIND_HARDWARE:		A Computer Hardware ID (CHID) to depend on system hardware
+ * @AS_RELATION_ITEM_KIND_INTERNET:		Internet connectivity (Since: 0.15.5)
  *
  * Type of the item an #AsRelation is for.
  **/
@@ -82,6 +86,8 @@ typedef enum  {
 	AS_RELATION_ITEM_KIND_FIRMWARE,
 	AS_RELATION_ITEM_KIND_CONTROL,
 	AS_RELATION_ITEM_KIND_DISPLAY_LENGTH,
+	AS_RELATION_ITEM_KIND_HARDWARE,
+	AS_RELATION_ITEM_KIND_INTERNET,
 	/*< private >*/
 	AS_RELATION_ITEM_KIND_LAST
 } AsRelationItemKind;
@@ -120,7 +126,8 @@ typedef enum {
  * @AS_CONTROL_KIND_GAMEPAD:	Gamepad input (any game controller with wheels/buttons/joysticks)
  * @AS_CONTROL_KIND_VOICE:	Control via voice recognition/activation
  * @AS_CONTROL_KIND_VISION:	Computer vision / visual object and sign detection
- * @AS_CONTROL_KIND_TV_REMOTE:	A television remote
+ * @AS_CONTROL_KIND_TV_REMOTE:	Input via a television remote
+ * @AS_CONTROL_KIND_TABLET:	Graphics tablet input
  *
  * Kind of an input method for users to control software
  **/
@@ -134,6 +141,7 @@ typedef enum {
 	AS_CONTROL_KIND_VOICE,
 	AS_CONTROL_KIND_VISION,
 	AS_CONTROL_KIND_TV_REMOTE,
+	AS_CONTROL_KIND_TABLET,
 	/*< private >*/
 	AS_CONTROL_KIND_LAST
 } AsControlKind;
@@ -163,7 +171,7 @@ typedef enum  {
  * @AS_DISPLAY_LENGTH_KIND_LARGE:	Large display
  * @AS_DISPLAY_LENGTH_KIND_XLARGE:	Very large display
  *
- * A rought estimate of how large a given display length is.
+ * A rough estimate of how large a given display length is.
  **/
 typedef enum  {
 	AS_DISPLAY_LENGTH_KIND_UNKNOWN,
@@ -176,6 +184,27 @@ typedef enum  {
 	AS_DISPLAY_LENGTH_KIND_LAST
 } AsDisplayLengthKind;
 
+/**
+ * AsInternetKind:
+ * @AS_INTERNET_KIND_UNKNOWN:		Unknown
+ * @AS_INTERNET_KIND_ALWAYS:		Always requires/recommends internet
+ * @AS_INTERNET_KIND_OFFLINE_ONLY:	Application is offline-only
+ * @AS_INTERNET_KIND_FIRST_RUN:	Requires/Recommends internet on first run only
+ *
+ * Different internet connectivity requirements or recommendations for an
+ * application.
+ *
+ * Since: 0.15.5
+ **/
+typedef enum  {
+	AS_INTERNET_KIND_UNKNOWN,
+	AS_INTERNET_KIND_ALWAYS,
+	AS_INTERNET_KIND_OFFLINE_ONLY,
+	AS_INTERNET_KIND_FIRST_RUN,
+	/*< private >*/
+	AS_INTERNET_KIND_LAST
+} AsInternetKind;
+
 const gchar		*as_relation_kind_to_string (AsRelationKind kind);
 AsRelationKind		as_relation_kind_from_string (const gchar *kind_str);
 
@@ -195,6 +224,9 @@ AsDisplaySideKind	as_display_side_kind_from_string (const gchar *kind_str);
 const gchar		*as_display_length_kind_to_string (AsDisplayLengthKind kind);
 AsDisplayLengthKind	as_display_length_kind_from_string (const gchar *kind_str);
 
+const gchar		*as_internet_kind_to_string (AsInternetKind kind);
+AsInternetKind		as_internet_kind_from_string (const gchar *kind_str);
+
 AsRelation		*as_relation_new (void);
 
 AsRelationKind		as_relation_get_kind (AsRelation *relation);
@@ -236,6 +268,13 @@ AsDisplayLengthKind	as_relation_get_value_display_length_kind (AsRelation *relat
 void			as_relation_set_value_display_length_kind (AsRelation *relation,
 								   AsDisplayLengthKind kind);
 
+AsInternetKind		as_relation_get_value_internet_kind (AsRelation *relation);
+void			as_relation_set_value_internet_kind (AsRelation *relation,
+							     AsInternetKind kind);
+guint			as_relation_get_value_internet_bandwidth (AsRelation *relation);
+void			as_relation_set_value_internet_bandwidth (AsRelation *relation,
+								  guint bandwidth_mbitps);
+
 gboolean		as_relation_version_compare (AsRelation *relation,
 						     const gchar *version,
 						     GError **error);
